==> jakarta-jakartaeetck-9.0.0.zip: jakartaeetck/src/com/sun/ts/tests/ejb/ee/bb/entity/cmp20/complexpktest/TestBean.java <==
/*
 * Copyright (c) 2007, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

/*
 * $Id$
 */

package com.sun.ts.tests.ejb.ee.bb.entity.cmp20.complexpktest;

import com.sun.ts.lib.util.*;

import jakarta.ejb.*;
import java.rmi.*;
import java.util.*;

public interface TestBean extends EJBObject {
  // Business Methods for TestBean CMP Fields
  public Integer getId() throws RemoteException;

  public String getBrandName() throws RemoteException;

  public double getPrice() throws RemoteException;

  public void setPrice(double p) throws RemoteException;

  public Product getProduct() throws RemoteException;

  public void setProduct(Product p) throws RemoteException;

  // Miscellaneous Business Methods

  public String ping(String s) throws RemoteException;

  public void addLineItem(LineItem l) throws RemoteException;

  public void initLogging(Properties p) throws RemoteException;
}

==> jakarta-jakartaeetck-10.0.3.zip: jakartaeetck/src/com/sun/ts/tests/ejb/ee/bb/entity/cmp20/complexpktest/TestBean.java <==
/*
 * Copyright (c) 2007, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

/*
 * $Id$
 */

package com.sun.ts.tests.ejb.ee.bb.entity.cmp20.complexpktest;

import java.rmi.RemoteException;
import java.util.Properties;

import jakarta.ejb.EJBObject;

public interface TestBean extends EJBObject {
  // Business Methods for TestBean CMP Fields
  public Integer getId() throws RemoteException;

  public String getBrandName() throws RemoteException;

  public double getPrice() throws RemoteException;

  public void setPrice(double p) throws RemoteException;

  public Product getProduct() throws RemoteException;

  public void setProduct(Product p) throws RemoteException;

  // Miscellaneous Business Methods

  public String ping(String s) throws RemoteException;

  public void addLineItem(LineItem l) throws RemoteException;

  public void initLogging(Properties p) throws RemoteException;
}
